aboutsummaryrefslogtreecommitdiffstats
path: root/src/modules/notifier
diff options
context:
space:
mode:
authorGravatar Szymon Tomasz Stefanek2011-01-01 20:19:56 +0000
committerGravatar Szymon Tomasz Stefanek2011-01-01 20:19:56 +0000
commitc601b5a27f74b16158adafe429faefbe573e64a2 (patch)
treea3cde3206a45628f8ac86e8dfbdab70b20c3a831 /src/modules/notifier
parentprobable compilation fix for rijndaled/crypto++ (diff)
downloadKVIrc-c601b5a27f74b16158adafe429faefbe573e64a2.tar.gz
KVIrc-c601b5a27f74b16158adafe429faefbe573e64a2.tar.bz2
KVIrc-c601b5a27f74b16158adafe429faefbe573e64a2.zip
The big rename for modules. Still some details remaining.
git-svn-id: https://svn.kvirc.de/svn/trunk/kvirc@5284 17fca916-40b9-46aa-a4ea-0a15b648b75c
Diffstat (limited to 'src/modules/notifier')
-rw-r--r--src/modules/notifier/CMakeLists.txt12
-rw-r--r--src/modules/notifier/NotifierMessage.cpp (renamed from src/modules/notifier/notifiermessage.cpp)12
-rw-r--r--src/modules/notifier/NotifierMessage.h (renamed from src/modules/notifier/notifiermessage.h)18
-rw-r--r--src/modules/notifier/NotifierSettings.h (renamed from src/modules/notifier/notifiersettings.h)2
-rw-r--r--src/modules/notifier/NotifierWindow.cpp (renamed from src/modules/notifier/notifierwindow.cpp)122
-rw-r--r--src/modules/notifier/NotifierWindow.h (renamed from src/modules/notifier/notifierwindow.h)18
-rw-r--r--src/modules/notifier/NotifierWindowBorder.cpp (renamed from src/modules/notifier/notifierwindowborder.cpp)26
-rw-r--r--src/modules/notifier/NotifierWindowBorder.h (renamed from src/modules/notifier/notifierwindowborder.h)10
-rw-r--r--src/modules/notifier/NotifierWindowTab.cpp (renamed from src/modules/notifier/notifierwindowtab.cpp)44
-rw-r--r--src/modules/notifier/NotifierWindowTab.h (renamed from src/modules/notifier/notifierwindowtab.h)18
-rw-r--r--src/modules/notifier/libkvinotifier.cpp10
11 files changed, 146 insertions, 146 deletions
diff --git a/src/modules/notifier/CMakeLists.txt b/src/modules/notifier/CMakeLists.txt
index 2453bfdb1..78a1d0b5c 100644
--- a/src/modules/notifier/CMakeLists.txt
+++ b/src/modules/notifier/CMakeLists.txt
@@ -1,16 +1,16 @@
# CMakeLists for src/modules/notifier
SET(kvinotifier_MOC_HDRS
- notifierwindow.h
- notifierwindowtab.h
+ NotifierWindow.h
+ NotifierWindowTab.h
)
SET(kvinotifier_SRCS
libkvinotifier.cpp
- notifierwindow.cpp
- notifiermessage.cpp
- notifierwindowtab.cpp
- notifierwindowborder.cpp
+ NotifierWindow.cpp
+ NotifierMessage.cpp
+ NotifierWindowTab.cpp
+ NotifierWindowBorder.cpp
)
# After this call, files will be moc'ed to moc_kvi_*.cpp
diff --git a/src/modules/notifier/notifiermessage.cpp b/src/modules/notifier/NotifierMessage.cpp
index 67c43a244..6dc7977d7 100644
--- a/src/modules/notifier/notifiermessage.cpp
+++ b/src/modules/notifier/NotifierMessage.cpp
@@ -1,6 +1,6 @@
//=============================================================================
//
-// File : notifiermessage.cpp
+// File : NotifierMessage.cpp
// Creation date : Mar 02 Nov 2004 02:41:18 by Iacopo Palazzi
//
// This file is part of the KVIrc irc client distribution
@@ -23,8 +23,8 @@
//
//=============================================================================
-#include "notifiermessage.h"
-#include "notifiersettings.h"
+#include "NotifierMessage.h"
+#include "NotifierSettings.h"
#include "KviHtmlGenerator.h"
#include "KviOptions.h"
@@ -32,7 +32,7 @@
#include <QRect>
#include <QResizeEvent>
-KviNotifierMessage::KviNotifierMessage(QPixmap * pPixmap, const QString & szText)
+NotifierMessage::NotifierMessage(QPixmap * pPixmap, const QString & szText)
{
m_pLabel0 = 0;
m_pLabel1 = 0;
@@ -51,7 +51,7 @@ KviNotifierMessage::KviNotifierMessage(QPixmap * pPixmap, const QString & szText
updateGui();
}
-KviNotifierMessage::~KviNotifierMessage()
+NotifierMessage::~NotifierMessage()
{
if(m_pLabel0)
m_pLabel0->deleteLater();
@@ -61,7 +61,7 @@ KviNotifierMessage::~KviNotifierMessage()
m_pHBox->deleteLater();
}
-void KviNotifierMessage::updateGui()
+void NotifierMessage::updateGui()
{
bool bShowImages = KVI_OPTION_BOOL(KviOption_boolIrcViewShowImages);
diff --git a/src/modules/notifier/notifiersettings.h b/src/modules/notifier/NotifierSettings.h
index 1a0a29e42..28e53ef3b 100644
--- a/src/modules/notifier/notifiersettings.h
+++ b/src/modules/notifier/NotifierSettings.h
@@ -2,7 +2,7 @@
#define _NOTIFIER_SETTINGS_H_
//=============================================================================
//
-// File : notifiersettings.h
+// File : NotifierSettings.h
// Creation date : Thu 30 Dev 2004 21:21:33 by Iacopo Palazzi
//
// This file is part of the Notifier - KVIrc Distribution distribution
diff --git a/src/modules/notifier/notifierwindow.cpp b/src/modules/notifier/NotifierWindow.cpp
index f46b87c2d..07b3f86bb 100644
--- a/src/modules/notifier/notifierwindow.cpp
+++ b/src/modules/notifier/NotifierWindow.cpp
@@ -1,6 +1,6 @@
//=============================================================================
//
-// File : notifierwindow.cpp
+// File : NotifierWindow.cpp
// Creation date : Tue Jul 6 2004 20:25:12 CEST by Szymon Stefanek
//
// This file is part of the KVIrc irc client distribution
@@ -23,10 +23,10 @@
//=============================================================================
#include "kvi_settings.h"
-#include "notifiermessage.h"
-#include "notifierwindow.h"
-#include "notifierwindowborder.h"
-#include "notifierwindowtab.h"
+#include "NotifierMessage.h"
+#include "NotifierWindow.h"
+#include "NotifierWindowBorder.h"
+#include "NotifierWindowTab.h"
#include "KviIconManager.h"
#include "KviConfigurationFile.h"
@@ -50,9 +50,9 @@
#include <QPaintEvent>
#include <QMouseEvent>
-extern KviNotifierWindow * g_pNotifierWindow;
+extern NotifierWindow * g_pNotifierWindow;
-KviNotifierWindow::KviNotifierWindow()
+NotifierWindow::NotifierWindow()
: QWidget(0,
#if defined(COMPILE_ON_WINDOWS) || defined(COMPILE_ON_MINGW)
Qt::FramelessWindowHint |
@@ -79,7 +79,7 @@ KviNotifierWindow::KviNotifierWindow()
m_tStartedAt=0;
m_pAutoHideTimer = 0;
- m_pWndBorder = new KviNotifierWindowBorder();
+ m_pWndBorder = new NotifierWindowBorder();
setFocusPolicy(Qt::NoFocus);
setMouseTracking(true);
@@ -148,7 +148,7 @@ KviNotifierWindow::KviNotifierWindow()
QTimer::singleShot(0,this,SLOT(updateGui()));
}
-KviNotifierWindow::~KviNotifierWindow()
+NotifierWindow::~NotifierWindow()
{
stopShowHideTimer();
stopBlinkTimer();
@@ -157,7 +157,7 @@ KviNotifierWindow::~KviNotifierWindow()
m_pWndTabs->deleteLater();
}
-void KviNotifierWindow::updateGui()
+void NotifierWindow::updateGui()
{
setFont(KVI_OPTION_FONT(KviOption_fontNotifier));
QPalette palette=m_pLineEdit->palette();
@@ -167,12 +167,12 @@ void KviNotifierWindow::updateGui()
for(int i=0; i<m_pWndTabs->count();++i)
{
- ((KviNotifierWindowTab*)m_pWndTabs->widget(i))->updateGui();
+ ((NotifierWindowTab*)m_pWndTabs->widget(i))->updateGui();
}
}
-void KviNotifierWindow::addMessage(KviWindow * pWnd, const QString & szImageId, const QString & szText, unsigned int uMessageTime)
+void NotifierWindow::addMessage(KviWindow * pWnd, const QString & szImageId, const QString & szText, unsigned int uMessageTime)
{
QPixmap * pIcon;
QString szMessage = szText;
@@ -182,13 +182,13 @@ void KviNotifierWindow::addMessage(KviWindow * pWnd, const QString & szImageId,
else
pIcon = g_pIconManager->getImage(szImageId);
- KviNotifierMessage * pMessage = new KviNotifierMessage(pIcon ? new QPixmap(*pIcon) : 0,szMessage);
+ NotifierMessage * pMessage = new NotifierMessage(pIcon ? new QPixmap(*pIcon) : 0,szMessage);
//search for an existing tab
- KviNotifierWindowTab * pTab = 0, * pTmp = 0;
+ NotifierWindowTab * pTab = 0, * pTmp = 0;
for(int i=0; i < m_pWndTabs->count();++i)
{
- pTmp = (KviNotifierWindowTab*)m_pWndTabs->widget(i);
+ pTmp = (NotifierWindowTab*)m_pWndTabs->widget(i);
if(pTmp->wnd() == pWnd)
{
pTab = pTmp;
@@ -198,7 +198,7 @@ void KviNotifierWindow::addMessage(KviWindow * pWnd, const QString & szImageId,
if(!pTab)
{
- pTab = new KviNotifierWindowTab(pWnd, m_pWndTabs);
+ pTab = new NotifierWindowTab(pWnd, m_pWndTabs);
}
//if the notifier is already visible, don't steal the focus from the current tab!
@@ -236,7 +236,7 @@ void KviNotifierWindow::addMessage(KviWindow * pWnd, const QString & szImageId,
update();
}
-void KviNotifierWindow::stopShowHideTimer()
+void NotifierWindow::stopShowHideTimer()
{
if(!m_pShowHideTimer)
return;
@@ -244,7 +244,7 @@ void KviNotifierWindow::stopShowHideTimer()
m_pShowHideTimer = 0;
}
-void KviNotifierWindow::stopBlinkTimer()
+void NotifierWindow::stopBlinkTimer()
{
if(!m_pBlinkTimer)
return;
@@ -252,7 +252,7 @@ void KviNotifierWindow::stopBlinkTimer()
m_pBlinkTimer = 0;
}
-void KviNotifierWindow::stopAutoHideTimer()
+void NotifierWindow::stopAutoHideTimer()
{
if(!m_pAutoHideTimer)
return;
@@ -307,7 +307,7 @@ void KviNotifierWindow::stopAutoHideTimer()
#endif //COMPILE_ON_WINDOWS || COMPILE_ON_MINGW
#endif // COMPILE_KDE_SUPPORT
-void KviNotifierWindow::doShow(bool bDoAnimate)
+void NotifierWindow::doShow(bool bDoAnimate)
{
if(!KVI_OPTION_BOOL(KviOption_boolEnableNotifier))
return;
@@ -374,11 +374,11 @@ void KviNotifierWindow::doShow(bool bDoAnimate)
}
}
-bool KviNotifierWindow::shouldHideIfMainWindowGotAttention()
+bool NotifierWindow::shouldHideIfMainWindowGotAttention()
{
if(m_bDisableHideOnMainWindowGotAttention)
return false;
- KviNotifierWindowTab * pTab = (KviNotifierWindowTab *) m_pWndTabs->currentWidget();
+ NotifierWindowTab * pTab = (NotifierWindowTab *) m_pWndTabs->currentWidget();
if(!pTab)
return false;
if(!pTab->wnd())
@@ -386,7 +386,7 @@ bool KviNotifierWindow::shouldHideIfMainWindowGotAttention()
return pTab->wnd()->hasAttention();
}
-void KviNotifierWindow::heartbeat()
+void NotifierWindow::heartbeat()
{
bool bIncreasing;
double targetOpacity = 0;
@@ -475,7 +475,7 @@ void KviNotifierWindow::heartbeat()
}
}
-void KviNotifierWindow::hideNow()
+void NotifierWindow::hideNow()
{
stopBlinkTimer();
stopShowHideTimer();
@@ -486,7 +486,7 @@ void KviNotifierWindow::hideNow()
hide();
}
-void KviNotifierWindow::doHide(bool bDoAnimate)
+void NotifierWindow::doHide(bool bDoAnimate)
{
stopAutoHideTimer();
switch(m_eState)
@@ -539,12 +539,12 @@ void KviNotifierWindow::doHide(bool bDoAnimate)
}
}
-void KviNotifierWindow::showEvent(QShowEvent *)
+void NotifierWindow::showEvent(QShowEvent *)
{
setGeometry(m_wndRect);
}
-void KviNotifierWindow::hideEvent(QHideEvent *)
+void NotifierWindow::hideEvent(QHideEvent *)
{
if(m_bCrashShowWorkAround)
return;
@@ -556,7 +556,7 @@ void KviNotifierWindow::hideEvent(QHideEvent *)
m_bDisableHideOnMainWindowGotAttention = false;
}
-void KviNotifierWindow::startBlinking()
+void NotifierWindow::startBlinking()
{
stopBlinkTimer();
m_bBlinkOn = false;
@@ -570,7 +570,7 @@ void KviNotifierWindow::startBlinking()
}
}
-void KviNotifierWindow::startAutoHideTimer()
+void NotifierWindow::startAutoHideTimer()
{
stopAutoHideTimer();
m_tStartedAt = kvi_unixTime();
@@ -586,7 +586,7 @@ void KviNotifierWindow::startAutoHideTimer()
m_pAutoHideTimer->start(100);
}
-void KviNotifierWindow::blink()
+void NotifierWindow::blink()
{
m_iBlinkCount++;
m_bBlinkOn = !m_bBlinkOn;
@@ -608,7 +608,7 @@ void KviNotifierWindow::blink()
update();
}
-void KviNotifierWindow::paintEvent(QPaintEvent * e)
+void NotifierWindow::paintEvent(QPaintEvent * e)
{
QPainter * pPaint = new QPainter(this);
@@ -626,7 +626,7 @@ void KviNotifierWindow::paintEvent(QPaintEvent * e)
pPaint->setFont(KVI_OPTION_FONT(KviOption_fontNotifierTitle));
QString szTitle = "KVIrc - ";
- KviNotifierWindowTab * pTab = (KviNotifierWindowTab *)m_pWndTabs->currentWidget();
+ NotifierWindowTab * pTab = (NotifierWindowTab *)m_pWndTabs->currentWidget();
if(pTab)
{
if(pTab->wnd())
@@ -644,7 +644,7 @@ void KviNotifierWindow::paintEvent(QPaintEvent * e)
e->ignore();
}
-void KviNotifierWindow::mouseMoveEvent(QMouseEvent * e)
+void NotifierWindow::mouseMoveEvent(QMouseEvent * e)
{
if(!m_bLeftButtonIsPressed)
{
@@ -684,7 +684,7 @@ sartelo:
}
}
-void KviNotifierWindow::mousePressEvent(QMouseEvent * e)
+void NotifierWindow::mousePressEvent(QMouseEvent * e)
{
// stop blinking first of all :)
bool bWasBlinkOn = m_bBlinkOn;
@@ -737,7 +737,7 @@ void KviNotifierWindow::mousePressEvent(QMouseEvent * e)
update();
}
-void KviNotifierWindow::mouseReleaseEvent(QMouseEvent * e)
+void NotifierWindow::mouseReleaseEvent(QMouseEvent * e)
{
m_bWriteDown = false;
m_bNextDown = false;
@@ -765,7 +765,7 @@ void KviNotifierWindow::mouseReleaseEvent(QMouseEvent * e)
setCursor(-1);
}
-void KviNotifierWindow::keyPressEvent(QKeyEvent * e)
+void NotifierWindow::keyPressEvent(QKeyEvent * e)
{
if(e->key() == Qt::Key_Escape)
{
@@ -774,7 +774,7 @@ void KviNotifierWindow::keyPressEvent(QKeyEvent * e)
}
}
-bool KviNotifierWindow::checkResizing(QPoint e)
+bool NotifierWindow::checkResizing(QPoint e)
{
if(e.y() < WDG_BORDER_THICKNESS)
{
@@ -863,7 +863,7 @@ bool KviNotifierWindow::checkResizing(QPoint e)
return m_bResizing;
}
-void KviNotifierWindow::resize(QPoint, bool)
+void NotifierWindow::resize(QPoint, bool)
{
if(m_whereResizing == WDG_UPSX || m_whereResizing == WDG_SX || m_whereResizing == WDG_DWNSX)
{
@@ -901,7 +901,7 @@ void KviNotifierWindow::resize(QPoint, bool)
setGeometry(m_wndRect);
}
-inline void KviNotifierWindow::setCursor(int iCur)
+inline void NotifierWindow::setCursor(int iCur)
{
if(m_cursor.shape() != iCur)
{
@@ -916,7 +916,7 @@ inline void KviNotifierWindow::setCursor(int iCur)
}
}
-void KviNotifierWindow::enterEvent(QEvent *)
+void NotifierWindow::enterEvent(QEvent *)
{
if(!m_pShowHideTimer)
{
@@ -927,7 +927,7 @@ void KviNotifierWindow::enterEvent(QEvent *)
m_pShowHideTimer->start(40);
}
-void KviNotifierWindow::leaveEvent(QEvent *)
+void NotifierWindow::leaveEvent(QEvent *)
{
// Leaving the widget area, restore default cursor
m_pWndBorder->resetIcons();
@@ -947,7 +947,7 @@ void KviNotifierWindow::leaveEvent(QEvent *)
}
}
-void KviNotifierWindow::contextPopup(const QPoint & pos)
+void NotifierWindow::contextPopup(const QPoint & pos)
{
if(!m_pContextPopup)
{
@@ -959,7 +959,7 @@ void KviNotifierWindow::contextPopup(const QPoint & pos)
m_pContextPopup->popup(pos);
}
-void KviNotifierWindow::fillContextPopup()
+void NotifierWindow::fillContextPopup()
{
m_pContextPopup->clear();
m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_EDITOR)),__tr2qs_ctx("Show/Hide input line","notifier"),this,SLOT(toggleLineEdit()));
@@ -978,7 +978,7 @@ void KviNotifierWindow::fillContextPopup()
m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUIT)),__tr2qs_ctx("Disable","notifier"),m_pDisablePopup);
}
-void KviNotifierWindow::disableFor15Minutes()
+void NotifierWindow::disableFor15Minutes()
{
kvi_time_t tNow = kvi_unixTime();
g_tNotifierDisabledUntil = tNow + (60 * 15);
@@ -986,7 +986,7 @@ void KviNotifierWindow::disableFor15Minutes()
hideNow();
}
-void KviNotifierWindow::disableFor5Minutes()
+void NotifierWindow::disableFor5Minutes()
{
kvi_time_t tNow = kvi_unixTime();
g_tNotifierDisabledUntil = tNow + (60 * 5);
@@ -995,7 +995,7 @@ void KviNotifierWindow::disableFor5Minutes()
}
-void KviNotifierWindow::disableFor1Minute()
+void NotifierWindow::disableFor1Minute()
{
kvi_time_t tNow = kvi_unixTime();
g_tNotifierDisabledUntil = tNow + 60;
@@ -1003,7 +1003,7 @@ void KviNotifierWindow::disableFor1Minute()
hideNow();
}
-void KviNotifierWindow::disableFor30Minutes()
+void NotifierWindow::disableFor30Minutes()
{
kvi_time_t tNow = kvi_unixTime();
g_tNotifierDisabledUntil = tNow + (60 * 30);
@@ -1011,7 +1011,7 @@ void KviNotifierWindow::disableFor30Minutes()
hideNow();
}
-void KviNotifierWindow::disableFor60Minutes()
+void NotifierWindow::disableFor60Minutes()
{
kvi_time_t tNow = kvi_unixTime();
g_tNotifierDisabledUntil = tNow + (60 * 60);
@@ -1019,7 +1019,7 @@ void KviNotifierWindow::disableFor60Minutes()
hideNow();
}
-void KviNotifierWindow::disableUntilKVIrcRestarted()
+void NotifierWindow::disableUntilKVIrcRestarted()
{
kvi_time_t tNow = kvi_unixTime();
// in fact we just disable for one year
@@ -1029,30 +1029,30 @@ void KviNotifierWindow::disableUntilKVIrcRestarted()
hideNow();
}
-void KviNotifierWindow::disablePermanently()
+void NotifierWindow::disablePermanently()
{
KVI_OPTION_BOOL(KviOption_boolEnableNotifier) = false;
hideNow();
}
-void KviNotifierWindow::toggleLineEdit()
+void NotifierWindow::toggleLineEdit()
{
showLineEdit(!m_pLineEdit->isVisible());
}
-void KviNotifierWindow::showLineEdit(bool bShow)
+void NotifierWindow::showLineEdit(bool bShow)
{
if(bShow)
{
if(m_pLineEdit->isVisible())
return;
- if(!((KviNotifierWindowTab *)m_pWndTabs->currentWidget())->wnd())
+ if(!((NotifierWindowTab *)m_pWndTabs->currentWidget())->wnd())
return;
m_pLineEdit->setToolTip("");
QString szTip = __tr2qs_ctx("Write text or commands to window","notifier");
szTip += " \"";
- szTip += ((KviNotifierWindowTab *)m_pWndTabs->currentWidget())->wnd()->plainTextCaption();
+ szTip += ((NotifierWindowTab *)m_pWndTabs->currentWidget())->wnd()->plainTextCaption();
szTip += "\"";
m_pLineEdit->setToolTip(szTip);
m_pLineEdit->show();
@@ -1067,7 +1067,7 @@ void KviNotifierWindow::showLineEdit(bool bShow)
}
}
-bool KviNotifierWindow::eventFilter(QObject * pEdit, QEvent * e)
+bool NotifierWindow::eventFilter(QObject * pEdit, QEvent * e)
{
if(pEdit != (QObject *)m_pLineEdit)
return false; // huh ?
@@ -1097,12 +1097,12 @@ bool KviNotifierWindow::eventFilter(QObject * pEdit, QEvent * e)
return false;
}
-void KviNotifierWindow::returnPressed()
+void NotifierWindow::returnPressed()
{
if(!m_pLineEdit->isVisible())
return;
- KviNotifierWindowTab * pTab = (KviNotifierWindowTab *) m_pWndTabs->currentWidget();
+ NotifierWindowTab * pTab = (NotifierWindowTab *) m_pWndTabs->currentWidget();
if(!pTab)
return;
if(!pTab->wnd())
@@ -1121,7 +1121,7 @@ void KviNotifierWindow::returnPressed()
KviUserInput::parse(szTxt,pTab->wnd(),QString(),1);
}
-void KviNotifierWindow::progressUpdate()
+void NotifierWindow::progressUpdate()
{
kvi_time_t now = kvi_unixTime();
int iProgress = (int)(100/(m_tAutoHideAt - m_tStartedAt)*(now - m_tStartedAt));
@@ -1134,11 +1134,11 @@ void KviNotifierWindow::progressUpdate()
}
}
-void KviNotifierWindow::slotTabCloseRequested(int iIndex)
+void NotifierWindow::slotTabCloseRequested(int iIndex)
{
if(m_pWndTabs)
{
- KviNotifierWindowTab * pTab = (KviNotifierWindowTab *) m_pWndTabs->widget(iIndex);
+ NotifierWindowTab * pTab = (NotifierWindowTab *) m_pWndTabs->widget(iIndex);
m_pWndTabs->removeTab(iIndex);
if(pTab)
pTab->deleteLater();
@@ -1149,5 +1149,5 @@ void KviNotifierWindow::slotTabCloseRequested(int iIndex)
}
#ifndef COMPILE_USE_STANDALONE_MOC_SOURCES
-#include "m_notifierwindow.moc"
+#include "m_NotifierWindow.moc"
#endif //!COMPILE_USE_STANDALONE_MOC_SOURCES
diff --git a/src/modules/notifier/notifierwindow.h b/src/modules/notifier/NotifierWindow.h
index 10e1b8c6a..d58cde2ae 100644
--- a/src/modules/notifier/notifierwindow.h
+++ b/src/modules/notifier/NotifierWindow.h
@@ -2,7 +2,7 @@
#define _NOTIFIERWINDOW_H_
//=============================================================================
//
-// File : notifierwindow.h
+// File : NotifierWindow.h
// Creation date : Tue Jul 6 2004 20:25:12 CEST by Szymon Stefanek
//
// This file is part of the KVIrc irc client distribution
@@ -25,7 +25,7 @@
//
//=============================================================================
-#include "notifiersettings.h"
+#include "NotifierSettings.h"
#include "kvi_settings.h"
#include "KviQString.h"
@@ -47,19 +47,19 @@
class QPainter;
class KviWindow;
-class KviNotifierMessage;
-class KviNotifierWindowBorder;
+class NotifierMessage;
+class NotifierWindowBorder;
class KviNotifierWindowTabs;
class KviThemedLineEdit;
extern kvi_time_t g_tNotifierDisabledUntil;
-class KviNotifierWindow : public QWidget
+class NotifierWindow : public QWidget
{
Q_OBJECT
public:
- KviNotifierWindow();
- ~KviNotifierWindow();
+ NotifierWindow();
+ ~NotifierWindow();
protected:
QTimer * m_pShowHideTimer;
QTimer * m_pBlinkTimer;
@@ -76,7 +76,7 @@ protected:
QRect m_wndRect;
- KviNotifierMessage * m_pCurrentMessage;
+ NotifierMessage * m_pCurrentMessage;
KviThemedLineEdit * m_pLineEdit;
bool m_bDragging;
@@ -102,7 +102,7 @@ protected:
QTabWidget * m_pWndTabs;
QProgressBar * m_pProgressBar;
- KviNotifierWindowBorder * m_pWndBorder;
+ NotifierWindowBorder * m_pWndBorder;
public:
void doShow(bool bDoAnimate);
void doHide(bool bDoAnimate);
diff --git a/src/modules/notifier/notifierwindowborder.cpp b/src/modules/notifier/NotifierWindowBorder.cpp
index c8c94c3f5..a47d3a64c 100644
--- a/src/modules/notifier/notifierwindowborder.cpp
+++ b/src/modules/notifier/NotifierWindowBorder.cpp
@@ -1,6 +1,6 @@
//=============================================================================
//
-// File : notifierwindowborder.cpp
+// File : NotifierWindowBorder.cpp
// Creation date : Mon 03 Jan 2005 02:27:22 by Iacopo Palazzi
//
// This file is part of the KVIrc distribution
@@ -22,24 +22,24 @@
//
//=============================================================================
-#include "notifierwindowborder.h"
-#include "notifierwindowtab.h"
+#include "NotifierWindowBorder.h"
+#include "NotifierWindowTab.h"
#include "KviIconManager.h"
#include <QPainter>
-KviNotifierWindowBorder::KviNotifierWindowBorder(QSize s)
+NotifierWindowBorder::NotifierWindowBorder(QSize s)
{
loadImages();
resize(s);
}
-KviNotifierWindowBorder::~KviNotifierWindowBorder()
+NotifierWindowBorder::~NotifierWindowBorder()
{
}
-void KviNotifierWindowBorder::loadImages()
+void NotifierWindowBorder::loadImages()
{
// Normal Border
@@ -103,7 +103,7 @@ void KviNotifierWindowBorder::loadImages()
}
-void KviNotifierWindowBorder::setPics(bool b)
+void NotifierWindowBorder::setPics(bool b)
{
if (b) {
m_pixSX = &m_pixSX_HL;
@@ -132,19 +132,19 @@ void KviNotifierWindowBorder::setPics(bool b)
}
}
-void KviNotifierWindowBorder::setWidth(int w)
+void NotifierWindowBorder::setWidth(int w)
{
m_iRctWidth = w;
recalculatePositions();
}
-void KviNotifierWindowBorder::setHeight(int h)
+void NotifierWindowBorder::setHeight(int h)
{
m_iRctHeight = h;
recalculatePositions();
}
-void KviNotifierWindowBorder::recalculatePositions()
+void NotifierWindowBorder::recalculatePositions()
{
m_rct.setHeight(m_iRctHeight);
m_rct.setWidth(m_iRctWidth);
@@ -166,7 +166,7 @@ void KviNotifierWindowBorder::recalculatePositions()
}
-void KviNotifierWindowBorder::setCloseIcon(int state)
+void NotifierWindowBorder::setCloseIcon(int state)
{
m_eIconState = state;
switch (m_eIconState) {
@@ -176,12 +176,12 @@ void KviNotifierWindowBorder::setCloseIcon(int state)
};
}
-void KviNotifierWindowBorder::resetIcons()
+void NotifierWindowBorder::resetIcons()
{
setCloseIcon(WDG_ICON_OUT);
}
-void KviNotifierWindowBorder::draw(QPainter * p, bool b)
+void NotifierWindowBorder::draw(QPainter * p, bool b)
{
setPics(b);
setCloseIcon(m_eIconState);
diff --git a/src/modules/notifier/notifierwindowborder.h b/src/modules/notifier/NotifierWindowBorder.h
index d5a6bbcb0..b59d90b74 100644
--- a/src/modules/notifier/notifierwindowborder.h
+++ b/src/modules/notifier/NotifierWindowBorder.h
@@ -2,7 +2,7 @@
#define _KVINOTIFIERWINDOWBORDER_H_
//=============================================================================
//
-// File : notifierwindowborder.h
+// File : NotifierWindowBorder.h
// Creation date : Mon 03 Jan 2005 02:27:22 by Iacopo Palazzi
//
// This file is part of the KVIrc distribution
@@ -24,7 +24,7 @@
//
//=============================================================================
-#include "notifiersettings.h"
+#include "NotifierSettings.h"
#include <QSize>
#include <QRect>
@@ -32,11 +32,11 @@
class QPainter;
-class KviNotifierWindowBorder
+class NotifierWindowBorder
{
public:
- KviNotifierWindowBorder(QSize = QSize(WDG_MIN_WIDTH,WDG_MIN_HEIGHT));
- ~KviNotifierWindowBorder();
+ NotifierWindowBorder(QSize = QSize(WDG_MIN_WIDTH,WDG_MIN_HEIGHT));
+ ~NotifierWindowBorder();
// ================================
// Put members declaration below...
diff --git a/src/modules/notifier/notifierwindowtab.cpp b/src/modules/notifier/NotifierWindowTab.cpp
index 7f48d15f6..dc47a3535 100644
--- a/src/modules/notifier/notifierwindowtab.cpp
+++ b/src/modules/notifier/NotifierWindowTab.cpp
@@ -1,7 +1,7 @@
//=============================================================================
//
-// File : notifierwindowtab.cpp
-// File : notifierwindowtab.h
+// File : NotifierWindowTab.cpp
+// File : NotifierWindowTab.h
// Creation date : Tue 07 Jul 2009 10:28 by Fabio Bas
//
// This file is part of the KVIrc distribution
@@ -23,10 +23,10 @@
//
//=============================================================================
-#include "notifiermessage.h"
-#include "notifierwindowtab.h"
-#include "notifierwindow.h"
-#include "notifiersettings.h"
+#include "NotifierMessage.h"
+#include "NotifierWindowTab.h"
+#include "NotifierWindow.h"
+#include "NotifierSettings.h"
#include "KviApplication.h"
#include "KviConfigurationFile.h"
@@ -48,9 +48,9 @@
extern KVIRC_API QPixmap * g_pShadedChildGlobalDesktopBackground;
#endif
-extern KviNotifierWindow * g_pNotifierWindow;
+extern NotifierWindow * g_pNotifierWindow;
-KviNotifierWindowTab::KviNotifierWindowTab(KviWindow * pWnd, QTabWidget * pParent)
+NotifierWindowTab::NotifierWindowTab(KviWindow * pWnd, QTabWidget * pParent)
: QScrollArea(pParent)
{
m_pWnd = pWnd;
@@ -88,7 +88,7 @@ KviNotifierWindowTab::KviNotifierWindowTab(KviWindow * pWnd, QTabWidget * pParen
setWidget(m_pVWidget);
}
-KviNotifierWindowTab::~KviNotifierWindowTab()
+NotifierWindowTab::~NotifierWindowTab()
{
if(m_pVBox)
m_pVBox->deleteLater();
@@ -96,7 +96,7 @@ KviNotifierWindowTab::~KviNotifierWindowTab()
m_pVWidget->deleteLater();
}
-void KviNotifierWindowTab::appendMessage(KviNotifierMessage * pMessage)
+void NotifierWindowTab::appendMessage(NotifierMessage * pMessage)
{
m_pVBox->addWidget(pMessage);
pMessage->setFixedWidth(viewport()->width());
@@ -104,31 +104,31 @@ void KviNotifierWindowTab::appendMessage(KviNotifierMessage * pMessage)
while(m_pVBox->count() > MAX_MESSAGES_IN_WINDOW)
{
QLayoutItem * pTmp = m_pVBox->takeAt(0);
- KviNotifierMessage * pTmp2 = (KviNotifierMessage*)pTmp->widget();
+ NotifierMessage * pTmp2 = (NotifierMessage*)pTmp->widget();
if(pTmp2)
pTmp2->deleteLater();
}
}
-void KviNotifierWindowTab::updateGui()
+void NotifierWindowTab::updateGui()
{
for(int i=0; i<m_pVBox->count(); ++i)
{
QLayoutItem * pTmp = m_pVBox->itemAt(i);
- KviNotifierMessage * pTmp2 = (KviNotifierMessage*)pTmp->widget();
+ NotifierMessage * pTmp2 = (NotifierMessage*)pTmp->widget();
if(pTmp2)
pTmp2->updateGui();
}
}
-void KviNotifierWindowTab::scrollRangeChanged(int, int)
+void NotifierWindowTab::scrollRangeChanged(int, int)
{
//this is the autoscroll
if(verticalScrollBar())
verticalScrollBar()->triggerAction(QAbstractSlider::SliderToMaximum);
}
-void KviNotifierWindowTab::labelChanged()
+void NotifierWindowTab::labelChanged()
{
if(!m_pWnd || !m_pParent)
return;
@@ -139,7 +139,7 @@ void KviNotifierWindowTab::labelChanged()
m_pParent->setTabText(iIdx, m_szLabel);
}
-void KviNotifierWindowTab::mouseDoubleClickEvent(QMouseEvent *)
+void NotifierWindowTab::mouseDoubleClickEvent(QMouseEvent *)
{
if(!m_pWnd || !g_pNotifierWindow)
return;
@@ -160,7 +160,7 @@ void KviNotifierWindowTab::mouseDoubleClickEvent(QMouseEvent *)
m_pWnd->frame()->setActiveWindow(m_pWnd);
}
-void KviNotifierWindowTab::closeMe()
+void NotifierWindowTab::closeMe()
{
//our window has been closed
if(m_pParent && g_pNotifierWindow)
@@ -173,22 +173,22 @@ void KviNotifierWindowTab::closeMe()
}
}
-void KviNotifierWindowTab::resizeEvent(QResizeEvent *)
+void NotifierWindowTab::resizeEvent(QResizeEvent *)
{
if(m_pVBox)
{
int iWidth = viewport()->width();
- KviNotifierMessage * pMessage;
+ NotifierMessage * pMessage;
for(int i=0; i < m_pVBox->count(); i++)
{
- pMessage = (KviNotifierMessage *)m_pVBox->itemAt(i)->widget();
+ pMessage = (NotifierMessage *)m_pVBox->itemAt(i)->widget();
if(pMessage)
pMessage->setFixedWidth(iWidth);
}
}
}
-void KviNotifierWindowTab::paintEvent(QPaintEvent * e)
+void NotifierWindowTab::paintEvent(QPaintEvent * e)
{
QPainter * pPainter = new QPainter(viewport());
@@ -226,5 +226,5 @@ void KviNotifierWindowTab::paintEvent(QPaintEvent * e)
}
#ifndef COMPILE_USE_STANDALONE_MOC_SOURCES
-#include "m_notifierwindowtab.moc"
+#include "m_NotifierWindowTab.moc"
#endif //!COMPILE_USE_STANDALONE_MOC_SOURCES
diff --git a/src/modules/notifier/notifierwindowtab.h b/src/modules/notifier/NotifierWindowTab.h
index 0e6edcdbe..5a07f387d 100644
--- a/src/modules/notifier/notifierwindowtab.h
+++ b/src/modules/notifier/NotifierWindowTab.h
@@ -2,7 +2,7 @@
#define _KVINOTIFIERWINDOWTAB_H_
//=============================================================================
//
-// File : notifierwindowtab.h
+// File : NotifierWindowTab.h
// Creation date : Tue 07 Jul 2009 10:28 by Fabio Bas
//
// This file is part of the KVIrc distribution
@@ -25,12 +25,12 @@
//=============================================================================
/**
-* \file notifierwindowtab.h
+* \file NotifierWindowTab.h
* \author Fabio Bas
* \brief Defines the tab page for the notifier object
*/
-#include "notifiermessage.h"
+#include "NotifierMessage.h"
#include "kvi_settings.h"
@@ -43,10 +43,10 @@ class QPainter;
class KviWindow;
/**
-* \class KviNotifierWindowTab
+* \class NotifierWindowTab
* \brief Defines an object for every single tab about the tabs area
*/
-class KviNotifierWindowTab : public QScrollArea
+class NotifierWindowTab : public QScrollArea
{
Q_OBJECT
public:
@@ -54,14 +54,14 @@ public:
* \brief Creates the tab object
* \param pWnd The name of the window represented by the tab
* \param pParent The parent area container
- * \return KviNotifierWindowTab
+ * \return NotifierWindowTab
*/
- KviNotifierWindowTab(KviWindow * pWnd, QTabWidget * pParent);
+ NotifierWindowTab(KviWindow * pWnd, QTabWidget * pParent);
/**
* \brief Destroys the tab object
*/
- ~KviNotifierWindowTab();
+ ~NotifierWindowTab();
private:
QString m_szLabel;
KviWindow * m_pWnd;
@@ -74,7 +74,7 @@ public:
* \param pMessage The message received to append
* \return void
*/
- void appendMessage(KviNotifierMessage * pMessage);
+ void appendMessage(NotifierMessage * pMessage);
/**
* \brief Updates the GUI
diff --git a/src/modules/notifier/libkvinotifier.cpp b/src/modules/notifier/libkvinotifier.cpp
index 0b71a6450..1943faffc 100644
--- a/src/modules/notifier/libkvinotifier.cpp
+++ b/src/modules/notifier/libkvinotifier.cpp
@@ -23,8 +23,8 @@
//
//=============================================================================
-#include "notifierwindow.h"
-#include "notifiermessage.h"
+#include "NotifierWindow.h"
+#include "NotifierMessage.h"
#include "KviModule.h"
#include "KviKvsVariant.h"
@@ -38,7 +38,7 @@
#include <QSplitter>
-KviNotifierWindow * g_pNotifierWindow = 0;
+NotifierWindow * g_pNotifierWindow = 0;
kvi_time_t g_tNotifierDisabledUntil = 0;
/*
@@ -119,7 +119,7 @@ static bool notifier_kvs_cmd_message(KviKvsModuleCommandCall * c)
KVSM_PARAMETERS_END(c)
if(!g_pNotifierWindow)
- g_pNotifierWindow = new KviNotifierWindow();
+ g_pNotifierWindow = new NotifierWindow();
QString szIco="";
QString szWnd="";
@@ -293,7 +293,7 @@ static bool notifier_module_ctrl(KviModule *, const char * pcOperation, void * p
return false;
if(!g_pNotifierWindow)
- g_pNotifierWindow = new KviNotifierWindow();
+ g_pNotifierWindow = new NotifierWindow();
g_pNotifierWindow->addMessage(p->pWindow,p->szIcon,p->szMessage,p->uMessageLifetime);
g_pNotifierWindow->doShow(KVI_OPTION_BOOL(KviOption_boolNotifierFading) ? true : false);
diff --git a/src/modules/notifier/notifiermessage.h b/src/modules/notifier/NotifierMessage.h
index 518a15098..025e5a11d 100644
--- a/src/modules/notifier/notifiermessage.h
+++ b/src/modules/notifier/NotifierMessage.h
@@ -2,7 +2,7 @@
#define _NOTIFIERMESSAGE_H_
//=============================================================================
//
-// File : notifiermessage.h
+// File : NotifierMessage.h
// Creation date : Mar 02 Nov 2004 02:41:18 by Iacopo Palazzi
//
// This file is part of the KVIrc distribution
@@ -33,28 +33,28 @@
#include <QWidget>
/**
-* \class KviNotifierMessage
+* \class NotifierMessage
* \brief A single message in a notifier window
*
* This is basically a single message that can appear in a notifier window
* It's made up of an icon and a rich text content
* This class is basically a QLabel with a method that translates a raw irc message to html code.
*/
-class KviNotifierMessage : public QWidget
+class NotifierMessage : public QWidget
{
- friend class KviNotifierWindow;
+ friend class NotifierWindow;
public:
/**
* \brief Constructs the KviNotifierMessage object
* \param pPixmap pointer to a message icon, can be null
* \param szText const reference to message text in irc format
- * \return KviNotifierMessage
+ * \return NotifierMessage
*/
- KviNotifierMessage(QPixmap * pPixmap, const QString &szText);
+ NotifierMessage(QPixmap * pPixmap, const QString &szText);
/**
* \brief Destroys the KviNotifierMessage object
*/
- ~KviNotifierMessage();
+ ~NotifierMessage();
private:
/// The message text
QString m_szText;
@@ -33,28 +33,28 @@
public:
/**
- * \brief Constructs the KviNotifierMessage object
+ * \brief Constructs the NotifierMessage object
* \param pPixmap pointer to a message icon, can be null
* \param szText const reference to message text in irc format
@@ -33,28 +33,28 @@
/**
- * \brief Destroys the KviNotifierMessage object
+ * \brief Destroys the NotifierMessage object
*/